@@ -3,23 +3,27 @@ ApproveAssignment <-
 ApproveAssignments <-
 function (assignments, feedback = NULL, rejected = FALSE,
     verbose = getOption('MTurkR.verbose', TRUE), ...) {
-    if(is.factor(assignments))
+    if (is.factor(assignments)) {
         assignments <- as.character(assignments)
-    if(rejected == TRUE) 
+    }
+    if (rejected == TRUE) {
         operation <- "ApproveRejectedAssignment"
-    else
+    } else {
         operation <- "ApproveAssignment"
-    if(!is.null(feedback)) {
-        if(is.factor(feedback))
+    }
+    if (!is.null(feedback)) {
+        if (is.factor(feedback)) {
             feedback <- as.character(feedback)
-        for(i in 1:length(feedback)) {
+        }
+        for (i in 1:length(feedback)) {
             if (!is.null(feedback[i]) && nchar(curl_escape(feedback[i])) > 1024) 
                 warning("Feedback ", i, " is too long (1024 char max)")
         }
-        if(length(feedback) == 1) 
+        if (length(feedback) == 1) {
             feedback <- rep(feedback[1], length(assignments))
-        else if(!length(feedback) == length(assignments)) 
+        } else if (!length(feedback) == length(assignments)) {
             stop("Number of feedback is not 1 nor length(assignments)")
+        }
     }
     batch <- function(assignment, feedback.batch = NULL) {
         GETparameters <- paste("&AssignmentId=", assignment, sep = "")
@@ -28,27 +32,30 @@ function (assignments, feedback = NULL, rejected = FALSE,
                 curl_escape(feedback.batch), sep = "")
         }
         request <- request(operation, GETparameters = GETparameters, ...)
-        if(is.null(request$valid))
+        if (is.null(request$valid)) {
             return(request)
-        if(verbose) {
-            if(request$valid) 
+        }
+        if (verbose) {
+            if (request$valid) {
                 message("Assignment ", assignment, " Approved", sep = "")
-            else
+            } else {
                 warning("Invalid Request for ", assignment)
+            }
         }
         return(request)
     }
-    Assignments <- setNames(data.frame(matrix(nrow=length(assignments), ncol=3)),
-                    c("AssignmentId", "Feedback", "Valid"))
-    for(i in 1:length(assignments)) {
+    Assignments <- emptydf(length(assignments), 3, c("AssignmentId", "Feedback", "Valid"))
+    for (i in 1:length(assignments)) {
         x <- batch(assignments[i], feedback[i])
-        if (!is.null(feedback)) 
+        if (!is.null(feedback)) {
             Assignments[i, ] <- c(assignments[i], feedback[i], x$valid)
-        else
+        } else {
             Assignments[i, ] <- c(assignments[i], "", x$valid)
+        }
     }
     Assignments$Valid <- factor(Assignments$Valid, levels=c('TRUE','FALSE'))
-    if(verbose) 
+    if (verbose) {
         message(sum(x$valid), " Assignments Approved")
+    }
     return(Assignments)
 }
