@@ -8,19 +8,22 @@ function (qual = NULL, workers, value = "1", notify = FALSE, name = NULL,
     conditional.value = NULL, conditional.period = NULL, set.statistic.as.value = FALSE, 
     verbose = getOption('MTurkR.verbose', TRUE), ...) {
     operation <- "AssignQualification"
-    if(!is.null(qual) & is.factor(qual))
+    if (!is.null(qual) & is.factor(qual)) {
         qual <- as.character(qual)
-    if(is.factor(workers))
+    }
+    if (is.factor(workers)) {
         workers <- as.character(workers)
-    if(is.factor(value))
+    }
+    if (is.factor(value)) {
         value <- as.character(value)
-    for(i in 1:length(value)) {
-        if(is.null(value[i]) || is.na(value[i]) || value[i]=='') {
+    }
+    for (i in 1:length(value)) {
+        if (is.null(value[i]) || is.na(value[i]) || value[i]=='') {
             warning("Value ",i," not assigned; value assumed to be 1")
             value[i] <- "1"
-        }
-        else if(is.na(as.numeric(value[i])))
+        } else if(is.na(as.numeric(value[i]))) {
             stop("value ",i," is not or cannot be coerced to numeric")
+        }
     }
     worker <- NULL
     batch <- function(worker, value) {
@@ -29,20 +32,20 @@ function (qual = NULL, workers, value = "1", notify = FALSE, name = NULL,
                                "&IntegerValue=", value,
                                "&SendNotification=", tolower(notify), sep = "")        
         request <- request(operation, GETparameters = GETparameters, ...)
-        if(is.null(request$valid))
+        if (is.null(request$valid)) {
             return(request)
-        if(verbose) {
-            if(request$valid == TRUE) {
+        }
+        if (verbose) {
+            if (request$valid == TRUE) {
                 message("Qualification (", qual, ") Assigned to worker ", worker)
                 return(invisible(request))
-            }
-            else if(request$valid == FALSE) {
+            } else if(request$valid == FALSE) {
                 warning("Invalid Request for worker ",worker)
                 return(request)
             }
-        }
-        else
+        } else {
             return(invisible(request))
+        }
     }
     if (!is.null(name)) {
         if (!is.null(qual)) 
@@ -60,18 +63,19 @@ function (qual = NULL, workers, value = "1", notify = FALSE, name = NULL,
         qual <- as.character(type$QualificationTypeId)
     }
     qual.value <- value
-    Qualifications <- setNames(data.frame(matrix(ncol=5, nrow=length(workers))),
-        c("WorkerId", "QualificationTypeId", "Value", "Notified", "Valid"))
-    if(is.null(conditional.statistic)) {
-        for(i in 1:length(workers)) {
+    Qualifications <- emptydf(length(workers), 5, c("WorkerId", "QualificationTypeId", "Value", "Notified", "Valid"))
+    if (is.null(conditional.statistic)) {
+        for (i in 1:length(workers)) {
             x <- batch(workers[i], value)
-            if(is.null(x$valid))
+            if (is.null(x$valid)) {
                 return(request)
+            }
             Qualifications[i, ] = c(workers[i], qual, value, notify, x$valid)
         }
     } else {
-        if(is.null(conditional.comparator)) 
+        if (is.null(conditional.comparator)) {
             stop("No comparator specified for conditional")
+        }
         value.integer <- c("NumberAssignmentsApproved", "NumberAssignmentsRejected", 
             "NumberKnownAnswersCorrect", "NumberKnownAnswersIncorrect", 
             "NumberKnownAnswersEvaluated", "NumberPluralityAnswersCorrect", 
@@ -79,62 +83,63 @@ function (qual = NULL, workers, value = "1", notify = FALSE, name = NULL,
             "NumberHITsCompleted", "NumberHITsAssignable", "NumberHITsReviewable")
         value.double <- c("PercentAssignmentsApproved", "PercentAssignmentsRejected", 
             "PercentKnownAnswersCorrect", "PercentPluralityAnswersCorrect")
-        if(!conditional.statistic %in% value.integer & !conditional.statistic %in% 
-            value.double) 
+        if (!conditional.statistic %in% value.integer & !conditional.statistic %in% value.double) {
             stop("Conditional Statistic not valid")
-        else {
-            if(conditional.comparator == "<") 
-                conditional.comparator = "LessThan"
-            else if(conditional.comparator == "<=") 
-                conditional.comparator = "LessThanOrEqualTo"
-            else if(conditional.comparator == ">") 
-                conditional.comparator = "GreaterThan"
-            else if(conditional.comparator == ">=") 
-                conditional.comparator = "GreaterThanOrEqualTo"
-            else if(conditional.comparator == "==") 
-                conditional.comparator = "EqualTo"
-            else if(conditional.comparator == "!=") 
-                conditional.comparator = "NotEqualTo"
-            if(!conditional.comparator %in% c(    "LessThan", "LessThanOrEqualTo", "GreaterThan",
-                                                "GreaterThanOrEqualTo", "EqualTo", "NotEqualTo")) 
+        } else {
+            conditional.comparator <- 
+              switch(conditional.comparator,
+                     "<" = "LessThan",
+                     "<=" = "LessThanOrEqualTo",
+                     ">" = "GreaterThan",
+                     ">=" = "GreaterThanOrEqualTo",
+                     "==" = "EqualTo",
+                     "!=" = "NotEqualTo")
+            if (!conditional.comparator %in% c("LessThan", "LessThanOrEqualTo", "GreaterThan",
+                                              "GreaterThanOrEqualTo", "EqualTo", "NotEqualTo")) {
                 stop("Inappropriate comparator specified for conditional")
+            }
         }
-        if(is.null(conditional.period) || !conditional.period %in% 
-            c("LifeToDate", "ThirtyDays", "SevenDays", "OneDay")) 
+        if (is.null(conditional.period) || !conditional.period %in% 
+            c("LifeToDate", "ThirtyDays", "SevenDays", "OneDay")) {
             stop("Inappropriate or no period specified for conditional")
-        if(is.null(conditional.value)) 
+        }
+        if (is.null(conditional.value)) {
             stop("Statistic value not specified for conditional")
+        }
         conditional.value <- as.numeric(conditional.value)
-        if(is.na(conditional.value)) 
+        if (is.na(conditional.value)) {
             stop("Conditional value is non-numeric")
-        for(i in 1:length(workers)) {
+        }
+        for (i in 1:length(workers)) {
             x <- GetWorkerStatistic(workers[i], conditional.statistic, 
                                     conditional.period, ...)
-            if(set.statistic.as.value == TRUE) 
+            if (set.statistic.as.value == TRUE) {
                 value <- x
-            if(conditional.comparator == "LessThan") {
-                if(as.numeric(x$value) < conditional.value) 
-                    temp <- batch(workers[i], value)
             }
-            else if(conditional.comparator == "LessThanOrEqualTo") {
-                if(as.numeric(x$value) <= conditional.value) 
+            if (conditional.comparator == "LessThan") {
+                if (as.numeric(x$value) < conditional.value) {
                     temp <- batch(workers[i], value)
-            }
-            else if(conditional.comparator == "GreaterThan") {
-                if(as.numeric(x$value) > conditional.value) 
+                }
+            } else if (conditional.comparator == "LessThanOrEqualTo") {
+                if (as.numeric(x$value) <= conditional.value) {
                     temp <- batch(workers[i], value)
-            }
-            else if(conditional.comparator == "GreaterThanOrEqualTo") {
-                if(as.numeric(x$value) >= conditional.value) 
+                }
+            } else if (conditional.comparator == "GreaterThan") {
+                if (as.numeric(x$value) > conditional.value) {
                     temp <- batch(workers[i], value)
-            }
-            else if(conditional.comparator == "EqualTo") {
-                if(as.numeric(x$value) == conditional.value) 
+                }
+            } else if (conditional.comparator == "GreaterThanOrEqualTo") {
+                if (as.numeric(x$value) >= conditional.value) {
                     temp <- batch(workers[i], value)
-            }
-            else if(conditional.comparator == "NotEqualTo") {
-                if(as.numeric(x$value) != conditional.value) 
+                }
+            } else if (conditional.comparator == "EqualTo") {
+                if (as.numeric(x$value) == conditional.value) {
                     temp <- batch(workers[i], value)
+                }
+            } else if (conditional.comparator == "NotEqualTo") {
+                if (as.numeric(x$value) != conditional.value) {
+                    temp <- batch(workers[i], value)
+                }
             }
             Qualifications[i, ] = c(workers[i], value, qual, notify, x$valid)
             value <- qual.value
