@@ -6,27 +6,29 @@ function(assignment,
          open.file.in.browser = FALSE, 
          verbose = getOption('MTurkR.verbose', TRUE), ...) {
     operation <- "GetFileUploadURL"
-    FileUploadURL <- setNames(data.frame(matrix(nrow = length(assignment), ncol = 4)),
-                        c("Assignment", "questionIdenfier", "RequestURL", "Valid"))
-    for(i in 1:length(assignment)) {
+    FileUploadURL <- emptydf(length(assignment), 4, c("Assignment", "questionIdenfier", "RequestURL", "Valid"))
+    for (i in 1:length(assignment)) {
         GETparameters <- paste("&AssignmentId=", curl_escape(assignment), 
                                "&QuestionIdentifier=", curl_escape(questionIdentifier), 
                                sep = "")        
         request <- request(operation, GETparameters = GETparameters, ...)
-        if(is.null(request$valid))
+        if (is.null(request$valid)) {
             return(request)
-        if(request$valid) {
+        }
+        if (request$valid) {
             u <- strsplit(strsplit(request$xml, "<FileUploadURL>")[[1]][2], "</FileUploadURL>")[[1]][1]
             FileUploadURL[i, ] <- c(assignment[i], questionIdentifier, u, request$valid)
-            if(verbose) 
+            if (verbose) {
                 message("FileUploadURL for Assignment ", assignment[i], " Retrieved: ", u)
-            if(open.file.in.browser) 
+            }
+            if (open.file.in.browser) {
                 browseURL(u)
-            if(download.file)
+            } else if (download.file) {
                 download.file(u, paste(questionIdentifier, "_", 
                                        assignment, "_", basename(u), 
                                        sep = ""), mode = "wb")
-        } else if(verbose) {
+            }
+        } else if (verbose) {
             message("Request for Assignment ", assignment[i], " failed")
         }
     }
