@@ -1,7 +1,9 @@
 OpenManageHITPage <-
 function (hit = NULL) {
-    if(is.null(hit)) 
+    if (is.null(hit)) {
         browseURL("https://requester.mturk.com/mturk/manageHITs")
-    if(!is.null(hit)) 
+    } else {
         browseURL(paste("https://requester.mturk.com/mturk/manageHIT?HITId=",hit,sep = ""))
+    }
+    invisible(NULL)
 }
