@@ -1,2 +1,4 @@
-OpenQualificationPage <- function ()
+OpenQualificationPage <- function () {
     browseURL("https://requester.mturk.com/qualification_types")
+    invisible(NULL)
+}
