@@ -6,17 +6,16 @@ function(xml.parsed,
          return.qual.list = TRUE, 
          sandbox = getOption('MTurkR.sandbox')) {
     hit.xml <- xpathApply(xml.parsed, "//HIT")
-    if(!is.null(length(hit.xml))) {
+    if (!is.null(length(hit.xml))) {
         quals <- list()
-        HITs <- setNames(data.frame(matrix(nrow = length(hit.xml), ncol = 19)),
-          c("HITId", "HITTypeId", "CreationTime", 
+        HITs <- emptydf(length(hit.xml), 19, c("HITId", "HITTypeId", "CreationTime", 
             "Title", "Description", "Keywords", "HITStatus", 
             "MaxAssignments", "Amount", "AutoApprovalDelayInSeconds", 
             "Expiration", "AssignmentDurationInSeconds", "NumberOfSimilarHITs", 
             "HITReviewStatus", "RequesterAnnotation", "NumberOfAssignmentsPending", 
             "NumberOfAssignmentsAvailable", "NumberOfAssignmentsCompleted", 
             "Question"))
-        for(i in 1:length(hit.xml)) {
+        for (i in 1:length(hit.xml)) {
             q <- xpathApply(xml.parsed, "//HIT")[[i]]
             HITs[i, 1] <- xmlValue(xmlChildren(q)$HITId)
             HITs[i, 2] <- xmlValue(xmlChildren(q)$HITTypeId)
@@ -26,8 +25,9 @@ function(xml.parsed,
             HITs[i, 6] <- xmlValue(xmlChildren(q)$Keywords)
             HITs[i, 7] <- xmlValue(xmlChildren(q)$HITStatus)
             HITs[i, 8] <- xmlValue(xmlChildren(q)$MaxAssignments)
-            if(!is.null(xmlChildren(q)$Reward))
+            if (!is.null(xmlChildren(q)$Reward)) {
                 HITs[i, 9] <- xmlValue(xmlChildren(xmlChildren(q)$Reward)$Amount)
+            }
             HITs[i, 10] <- xmlValue(xmlChildren(q)$AutoApprovalDelayInSeconds)
             HITs[i, 11] <- xmlValue(xmlChildren(q)$Expiration)
             HITs[i, 12] <- xmlValue(xmlChildren(q)$AssignmentDurationInSeconds)
@@ -38,30 +38,25 @@ function(xml.parsed,
             HITs[i, 17] <- xmlValue(xmlChildren(q)$NumberOfAssignmentsAvailable)
             HITs[i, 18] <- xmlValue(xmlChildren(q)$NumberOfAssignmentsCompleted)
             HITs[i, 19] <- xmlValue(xmlChildren(q)$Question)
-            if(return.qual.list == TRUE) {
+            if (return.qual.list == TRUE) {
                 quals.nodeset <- xpathApply(xml.parsed, paste("//HIT[", i,
                     "]/QualificationRequirement", sep = ""))
-                if(!is.null(quals.nodeset) && length(quals.nodeset) > 0) {
+                if (!is.null(quals.nodeset) && length(quals.nodeset) > 0) {
                     quals[[i]] <-
                         as.data.frame.QualificationRequirements(xmlnodeset = quals.nodeset, 
                                                                 hit.number = i,
                                                                 sandbox = sandbox)
-                    if(!is.null(quals[[i]])) {
+                    if (!is.null(quals[[i]])) {
                         quals[[i]]$HITId <- HITs$HITId[i]
                     }
                 } else {
-                    quals[[i]] <- setNames(data.frame(matrix(ncol=6, nrow=0)),
-                                           c('HITId', 'QualificationTypeId',
-                                             'Name', 'Comparator',
-                                             'Value', 'RequiredToPreview'))
+                    quals[[i]] <- emptydf(0, 6, c('HITId', 'QualificationTypeId', 'Name', 'Comparator', 'Value', 'RequiredToPreview'))
                 }
             }
         }
         return(list(HITs = HITs, QualificationRequirements = quals))
     } else {
-        return(list(HITs =
-                    setNames(data.frame(matrix(nrow = 0, ncol = 19)),
-                             c("HITId", "HITTypeId", "CreationTime", 
+        return(list(HITs = emptydf(0, 19, c("HITId", "HITTypeId", "CreationTime", 
                                "Title", "Description", "Keywords", "HITStatus", 
                                "MaxAssignments", "Amount", 
                                "AutoApprovalDelayInSeconds", "Expiration", 
@@ -95,8 +90,7 @@ as.data.frame.Assignments <- function(xml.parsed, return.assignment.xml = FALSE)
         ))
     })
     assignments <- do.call(rbind.data.frame, assignments)
-    assignments$HITId <- xmlValue(xpathApply(xml.parsed, 
-            paste("//HITId", sep = ""))[[1]])
+    assignments$HITId <- xmlValue(xpathApply(xml.parsed, paste("//HITId", sep = ""))[[1]])
     assignments$ApprovalRejectionTime <-
         ifelse(!is.na(assignments$ApprovalTime),
             assignments$ApprovalTime, assignments$RejectionTime)
@@ -107,13 +101,14 @@ as.data.frame.Assignments <- function(xml.parsed, return.assignment.xml = FALSE)
 
     # return answers and merge
     answers <- as.data.frame.QuestionFormAnswers(xml.parsed = xml.parsed)
-    values <- reshape(answers, timevar="QuestionIdentifier",
-                    direction="wide", idvar="AssignmentId",
-                    drop=c( "WorkerId","HITId","FreeText","SelectionIdentifier",
-                            "OtherSelectionField","UploadedFileKey","UploadedFileSizeInBytes"))
+    values <- reshape(answers, timevar = "QuestionIdentifier",
+                      direction = "wide", idvar = "AssignmentId",
+                      drop=c("WorkerId","HITId","FreeText","SelectionIdentifier",
+                             "OtherSelectionField","UploadedFileKey","UploadedFileSizeInBytes"))
     names(values) <- gsub("Combined.Answers.","",names(values),fixed=TRUE)
     assignments <- merge(assignments,values,by="AssignmentId",all=TRUE)
-    return(list(assignments = assignments, answers = answers))
+    return(list(assignments = setRownames(assignments), 
+                answers = answers))
 }
 
 
@@ -126,15 +121,15 @@ function(xml.parsed = NULL,
          xmlnodeset = NULL, 
          hit.number = NULL, 
          sandbox = getOption('MTurkR.sandbox')){
-    if(is.null(xmlnodeset) & is.null(xml.parsed)) 
+    if (is.null(xmlnodeset) & is.null(xml.parsed)) {
         stop("Must supply XML (parsed or unparsed) xor XMLNodeSet")
+    }
     batch <- function(xmlnodeset) {
-        quals <- setNames(data.frame(matrix(nrow = length(xmlnodeset), ncol = 6)),
-                          c("HITId", "QualificationTypeId", "Name",
-                            "Comparator", "Value", "RequiredToPreview"))
-        for(i in 1:length(xmlnodeset)) {
+        quals <- emptydf(nrow = length(xmlnodeset), ncol = 6,
+                         c("HITId", "QualificationTypeId", "Name", "Comparator", "Value", "RequiredToPreview"))
+        for (i in 1:length(xmlnodeset)) {
             quals$QualificationTypeId[i] <- xmlValue(xmlChildren(xmlnodeset[[i]])$QualificationTypeId)
-            if(quals$QualificationTypeId[i] %in% ListQualificationTypes()$QualificationTypeId) {
+            if (quals$QualificationTypeId[i] %in% ListQualificationTypes()$QualificationTypeId) {
                 qlist <- ListQualificationTypes()
                 quals$Name[i] <- qlist[qlist$QualificationTypeId == 
                   quals$QualificationTypeId[i], "Qualification"]
@@ -142,12 +137,12 @@ function(xml.parsed = NULL,
                 quals$Name[i] <- NA
             }
             quals$Comparator[i] <- xmlValue(xmlChildren(xmlnodeset[[i]])$Comparator)
-            if("LocaleValue" %in% names(xmlChildren(xmlnodeset[[i]]))) {
+            if ("LocaleValue" %in% names(xmlChildren(xmlnodeset[[i]]))) {
                 w <- which(names(xmlChildren(xmlnodeset[[i]])) == "LocaleValue")
                 locales <- sapply(xmlChildren(xmlnodeset[[i]])[w], xmlValue)
                 quals$Value[i] <- paste0(locales, collapse=",")
             }
-            if("IntegerValue" %in% names(xmlChildren(xmlnodeset[[i]]))) {
+            if ("IntegerValue" %in% names(xmlChildren(xmlnodeset[[i]]))) {
                 w <- which(names(xmlChildren(xmlnodeset[[i]])) == "IntegerValue")
                 locales <- sapply(xmlChildren(xmlnodeset[[i]])[w], xmlValue)
                 quals$Value[i] <- paste0(locales, collapse=",")
@@ -156,26 +151,22 @@ function(xml.parsed = NULL,
         }
         return(quals)
     }
-    if(!is.null(xmlnodeset)) {
+    if (!is.null(xmlnodeset)) {
         return(batch(xmlnodeset))
-    } else if(!is.null(xml.parsed)) {
-        if(!is.null(hit.number)) {
+    } else if (!is.null(xml.parsed)) {
+        if (!is.null(hit.number)) {
             xmlnodeset <- xpathApply(xml.parsed, paste("//HIT[", 
                 hit.number, "]/QualificationRequirement", sep = ""))
-        } else if(is.null(hit.number)) {
+        } else if (is.null(hit.number)) {
             xmlnodeset <- xpathApply(xml.parsed, "//QualificationRequirement")
         }
-        if(!is.null(xmlnodeset)) {
+        if (!is.null(xmlnodeset)) {
             return(batch(xmlnodeset))
         } else {
-            return(setNames(data.frame(matrix(ncol=6, nrow=0)),
-                   c('HITId', 'QualificationTypeId', 'Name',
-                     'Comparator', 'Value', 'RequiredToPreview')))
+            return(emptydf(0, 6, c('HITId', 'QualificationTypeId', 'Name', 'Comparator', 'Value', 'RequiredToPreview')))
         }
     } else {
-        return(setNames(data.frame(matrix(ncol=6, nrow=0)),
-                        c('HITId', 'QualificationTypeId', 'Name',
-                          'Comparator', 'Value', 'RequiredToPreview')))
+        return(emptydf(0, 6, c('HITId', 'QualificationTypeId', 'Name', 'Comparator', 'Value', 'RequiredToPreview')))
     }
 }
 
@@ -199,23 +190,13 @@ as.data.frame.QualificationTypes <- function(xml.parsed) {
             AnswerKey = xmlValue(children$AnswerKey)
         ))
     })
-    if(!length(out)){
-        return(setNames(data.frame(matrix(nrow=0, ncol=13)),
-                        c("QualificationTypeId",
-                          "CreationTime",
-                         "Name",
-                         "Description",
-                         "Keywords",
-                         "QualificationTypeStatus",
-                         "AutoGranted",
-                         "AutoGrantedValue",
-                         "IsRequestable",
-                         "RetryDelayInSeconds",
-                         "TestDurationInSeconds",
-                         "Test",
-                         "AnswerKey")))
-    } else
-        return(do.call(rbind.data.frame, out))
+    if (!length(out)) {
+        return(emptydf(0, 13, c("QualificationTypeId", "CreationTime", "Name", "Description", "Keywords",
+                                "QualificationTypeStatus", "AutoGranted", "AutoGrantedValue", "IsRequestable",
+                                "RetryDelayInSeconds", "TestDurationInSeconds", "Test", "AnswerKey")))
+    } else {
+        return(setRownames(do.call(rbind.data.frame, out)))
+    }
 }
 
 as.data.frame.QualificationRequests <- function(xml.parsed){
@@ -229,52 +210,54 @@ as.data.frame.QualificationRequests <- function(xml.parsed){
             Answer = xmlValue(children$Answer)
         ))
     })
-    if(!length(out)) {
-        return(setNames(data.frame(matrix(nrow=0, ncol=5)),
-                        c("QualificationRequestId",
-                          "QualificationTypeId",
-                          "SubjectId",
-                          "SubmitTime",
-                          "Answer")))
-    } else
-        return(do.call("rbind.data.frame", out))
+    if (!length(out)) {
+        return(emptydf(0, 5, c("QualificationRequestId","QualificationTypeId","SubjectId","SubmitTime","Answer")))
+    } else {
+        return(setRownames(do.call("rbind.data.frame", out)))
+    }
 }
 
 as.data.frame.Qualifications <- function(xml.parsed) {
     quals.xml <- xpathApply(xml.parsed, "//Qualification")
-    if(length(quals.xml) > 0) {
-        quals <- setNames(data.frame(matrix(nrow = length(quals.xml), ncol = 5)),
-                    c("QualificationTypeId", "WorkerId", "GrantTime", "Value", "Status"))
-        for(i in 1:length(quals.xml)) {
-            if("IntegerValue" %in% names(xmlChildren(quals.xml[[1]]))) 
+    if (length(quals.xml) > 0) {
+        quals <- emptydf(length(quals.xml), 5, c("QualificationTypeId", "WorkerId", "GrantTime", "Value", "Status"))
+        for (i in 1:length(quals.xml)) {
+            if ("IntegerValue" %in% names(xmlChildren(quals.xml[[1]]))) {
                 value.type <- "IntegerValue"
-            if("LocaleValue" %in% names(xmlChildren(quals.xml[[1]]))) 
+            }
+            if ("LocaleValue" %in% names(xmlChildren(quals.xml[[1]]))) {
                 value.type <- "LocaleValue"
+            }
             qual <- xpathApply(xml.parsed,
                 paste("//Qualification[", i, "]/QualificationTypeId", sep = ""))
-            if(length(qual) == 1) 
+            if (length(qual) == 1) {
                 quals[i, 1] <- xmlValue(qual[[1]])
+            }
             subj <- xpathApply(xml.parsed,
                 paste("//Qualification[", i, "]/SubjectId", sep = ""))
-            if(length(subj) == 1) 
+            if (length(subj) == 1) {
                 quals[i, 2] <- xmlValue(subj[[1]])
+            }
             time <- xpathApply(xml.parsed,
                 paste("//Qualification[", i, "]/GrantTime", sep = ""))
-            if(length(time) == 1) 
+            if (length(time) == 1) {
                 quals[i, 3] <- xmlValue(time[[1]])
+            }
             valu <- xpathApply(xml.parsed,
                 paste("//Qualification[", i, "]/", value.type, sep = ""))
-            if(length(valu) == 1) 
+            if (length(valu) == 1) {
                 quals[i, 4] <- xmlValue(valu[[1]])
+            }
             stat <- xpathApply(xml.parsed,
                 paste("//Qualification[", i, "]/Status", sep = ""))
-            if(length(stat) == 1) 
+            if (length(stat) == 1) {
                 quals[i, 5] <- xmlValue(stat[[1]])
+            }
         }
         return(Qualifications = quals)
-    }
-    else
+    } else {
         return(list(Qualifications = NULL))
+    }
 }
 
 
@@ -284,7 +267,7 @@ as.data.frame.QuestionForm <- function(xml.parsed) {
     qform <- xmlChildren(xmlChildren(xml.parsed)$QuestionForm)
     n <- names(qform)
     out <- mapply(function(x, name, elementnumber){
-        if(name=='Question'){
+        if (name=='Question'){
             list(ElementNumber = elementnumber,
                  Element = 'Question',
                  QuestionIdentifier = xmlValue(xmlChildren(x)$QuestionIdentifier),
@@ -292,7 +275,7 @@ as.data.frame.QuestionForm <- function(xml.parsed) {
                  IsRequired = xmlValue(xmlChildren(x)$IsRequired),
                  QuestionContent = toString.XMLNode(xmlChildren(x)$QuestionContent),
                  AnswerSpecification = toString.XMLNode(xmlChildren(x)$AnswerSpecification) )
-        } else if(name=='Overview'){
+        } else if (name=='Overview'){
             append(list(ElementNumber = elementnumber, 
                         Element = 'Overview'),
                 lapply(xmlChildren(x), xmlValue))
@@ -304,63 +287,58 @@ as.data.frame.QuestionForm <- function(xml.parsed) {
 
 as.data.frame.HTMLQuestion <- function(xml.parsed) {
     removeXMLNamespaces(xml.parsed, all = TRUE)
-    if(length(xmlChildren(xml.parsed)) > 0) {
+    if (length(xmlChildren(xml.parsed)) > 0) {
         html.content <- xmlValue(xmlChildren(xml.parsed)$HTMLContent)
         frame.height <- xmlValue(xmlChildren(xml.parsed)$FrameHeight)
         return(list(html.content = html.content, frame.height = frame.height))
-    }
-    else
+    } else {
         return(list(html.content = NULL, frame.height = NULL))
+    }
 }
 
 as.data.frame.ExternalQuestion <- function(xml.parsed) {
     removeXMLNamespaces(xml.parsed, all = TRUE)
-    if(length(xmlChildren(xml.parsed)) > 0) {
+    if (length(xmlChildren(xml.parsed)) > 0) {
         external.url <- xmlValue(xmlChildren(xml.parsed)$ExternalURL)
         frame.height <- xmlValue(xmlChildren(xml.parsed)$FrameHeight)
         return(list(external.url = external.url, frame.height = frame.height))
-    }
-    else
+    } else {
         return(list(external.url = NULL, frame.height = NULL))
+    }
 }
 
 as.data.frame.AnswerKey <- function(xml.parsed) {
     nodes <- xmlChildren(xmlChildren(xml.parsed)$AnswerKey)
     # need to change this to an xpath expression:
-    answerkey <- data.frame(matrix(nrow = length(strsplit(toString.XMLNode(xml.parsed),'/AnswerOption')[[1]])-1,
-                                   ncol = 3))
-    names(answerkey) <- c("QuestionIdentifier", "SelectionIdentifier", "AnswerScore")
+    answerkey <- emptydf(nrow = length(strsplit(toString.XMLNode(xml.parsed),'/AnswerOption')[[1]])-1,
+                         ncol = 3, c("QuestionIdentifier", "SelectionIdentifier", "AnswerScore"))
     k <- 1
-    for(i in 1:length(nodes[names(nodes) == "Question"])) {
+    for (i in 1:length(nodes[names(nodes) == "Question"])) {
         question <- xmlChildren(nodes[names(nodes) == "Question"][[i]])
         qid <- xmlValue(question$QuestionIdentifier)
         answeroptions <- question[names(question) == "AnswerOption"]
-        for(j in 1:length(answeroptions)) {
+        for (j in 1:length(answeroptions)) {
             answerkey$QuestionIdentifier[k] <- qid
             answerkey$SelectionIdentifier[k] <- xmlValue(xmlChildren(answeroptions[[j]])$SelectionIdentifier)
             answerkey$AnswerScore[k] <- xmlValue(xmlChildren(answeroptions[[j]])$AnswerScore)
             k <- k + 1
         }
     }
-    if(!is.null(nodes$QualificationValueMapping)) {
+    if (!is.null(nodes$QualificationValueMapping)) {
         map <- xmlChildren(nodes$QualificationValueMapping)
         mapping <- list()
-        if("PercentageMapping" %in% names(map)) {
+        if ("PercentageMapping" %in% names(map)) {
             mapping$Type <- "PercentageMapping"
             mapping$MaximumSummedScore <- xmlValue(xmlChildren(map$PercentageMapping)$MaximumSummedScore)
-        }
-        else if("ScaleMapping" %in% names(map)) {
+        } else if ("ScaleMapping" %in% names(map)) {
             mapping$Type <- "ScaleMapping"
             mapping$SummedScoreMultiplier <- xmlValue(xmlChildren(map$PercentageMapping)$SummedScoreMultiplier)
-        }
-        else if("RangeMapping" %in% names(map)) {
+        } else if ("RangeMapping" %in% names(map)) {
             mapping$Type <- "RangeMapping"
             ranges.xml <- xmlChildren(map$RangeMapping)
             scoreranges <- ranges.xml[names(ranges.xml) == "SummedScoreRange"]
-            mapping$Ranges <- data.frame(matrix(nrow=length(scoreranges), ncol=3))
-            names(mapping$Ranges) <- c("InclusiveLowerBound", 
-                "InclusiveUpperBound", "QualificationValue")
-            for(i in 1:length(scoreranges)) {
+            mapping$Ranges <- emptydf(length(scoreranges), 3, c("InclusiveLowerBound", "InclusiveUpperBound", "QualificationValue"))
+            for (i in 1:length(scoreranges)) {
                 mapping$Ranges[i, ] <- c(xmlValue(xmlChildren(scoreranges[[i]])$InclusiveLowerBound), 
                   xmlValue(xmlChildren(scoreranges[[i]])$InclusiveUpperBound), 
                   xmlValue(xmlChildren(scoreranges[[i]])$QualificationValue))
@@ -368,9 +346,9 @@ as.data.frame.AnswerKey <- function(xml.parsed) {
             mapping$OutOfRangeQualificationValue <- xmlValue(ranges.xml$OutOfRangeQualificationValue)
         }
         return(list(Questions = answerkey, Scoring = mapping))
-    }
-    else
+    } else {
         return(list(Questions = answerkey))
+    }
 }
 
 as.data.frame.QuestionFormAnswers <- function(xml.parsed) {
@@ -386,24 +364,23 @@ as.data.frame.QuestionFormAnswers <- function(xml.parsed) {
     questions <- xmlChildren(z)
     iterations <- total * length(questions)
     # create dataframe
-    values <- as.data.frame(matrix(nrow = iterations, ncol = 10))
-    names(values) <- c("AssignmentId", "WorkerId", "HITId", "QuestionIdentifier", 
-                       "FreeText", "SelectionIdentifier", "OtherSelectionField", 
-                       "UploadedFileKey", "UploadedFileSizeInBytes", "Combined.Answers")
+    values <- emptydf(iterations, 10, c("AssignmentId", "WorkerId", "HITId", "QuestionIdentifier", 
+                                        "FreeText", "SelectionIdentifier", "OtherSelectionField", 
+                                        "UploadedFileKey", "UploadedFileSizeInBytes", "Combined.Answers"))
     convertxml <- function(node){
         questions <- xmlChildren(extractQuestionFormAnswersElement(node))
-        out <- as.data.frame(matrix(nrow = length(questions), ncol = 10))
-        names(out) <- names(values)
+        out <- emptydf(length(questions), 10, names(values))
         out$AssignmentId <- xmlValue(xpathApply(node, "../AssignmentId")[[1]])
         out$WorkerId <- xmlValue(xpathApply(node, "../WorkerId")[[1]])
         out$HITId <- xmlValue(xpathApply(node, "../HITId")[[1]])
-        for(z in 1:length(questions)){
-            if(length(xmlChildren(questions[[z]])$QuestionIdentifier) == 1) 
+        for (z in 1:length(questions)) {
+            if (length(xmlChildren(questions[[z]])$QuestionIdentifier) == 1) {
                 out$QuestionIdentifier[z] <- xmlValue(xmlChildren(questions[[z]])$QuestionIdentifier)
-            if(length(xmlChildren(questions[[z]])$FreeText) == 1) {
+            }
+            if (length(xmlChildren(questions[[z]])$FreeText) == 1) {
                 out$FreeText[z] <- xmlValue(xmlChildren(questions[[z]])$FreeText)
                 out$Combined.Answers[z] <- xmlValue(xmlChildren(questions[[z]])$FreeText)
-            } else if(length(xmlChildren(questions[[z]])$UploadedFileKey) == 1) {
+            } else if (length(xmlChildren(questions[[z]])$UploadedFileKey) == 1) {
                 out$UploadedFileKey[z] <- xmlValue(xmlChildren(questions[[z]])$UploadedFileKey)
                 out$UploadedFileSizeInBytes[z] <- xmlValue(xmlChildren(questions[[z]])$UploadedFileSizeInBytes)
                 out$Combined.Answers[z] <- paste(out$UploadedFileKey[z], 
@@ -411,18 +388,18 @@ as.data.frame.QuestionFormAnswers <- function(xml.parsed) {
             } else if (sum(names(xmlChildren(questions[[z]])) == "SelectionIdentifier") == 1) {
                 out$SelectionIdentifier[z] <- xmlValue(xmlChildren(questions[[z]])$SelectionIdentifier)
                 out$Combined.Answers[z] <- xmlValue(xmlChildren(questions[[z]])$SelectionIdentifier)
-                if(length(xmlChildren(questions[[1]])$OtherSelectionField) == 1) {
+                if (length(xmlChildren(questions[[1]])$OtherSelectionField) == 1) {
                     multiple <- paste(out$SelectionIdentifier[z], 
                                 xmlValue(xmlChildren(questions[[z]])$OtherSelectionField), 
                                 sep = ";")
                     out$Combined.Answers[z] <- multiple
                     rm(multiple)
                 }
-            } else if(sum(names(xmlChildren(questions[[z]])) == "SelectionIdentifier") > 1) {
+            } else if (sum(names(xmlChildren(questions[[z]])) == "SelectionIdentifier") > 1) {
                 multiple <- ""
                 n <- names(xmlChildren(questions[[z]])) == "SelectionIdentifier"
                 multiple <- paste(unname(sapply(xmlChildren(questions[[1]])[n], xmlValue)), collapse = ";")
-                if(any(names(xmlChildren(questions[[z]])) == "OtherSelectionField")) { 
+                if (any(names(xmlChildren(questions[[z]])) == "OtherSelectionField")) { 
                     multiple <- paste(multiple,
                                 xmlValue(xmlChildren(questions[[z]])$OtherSelectionField), 
                                 sep = ";")
@@ -430,15 +407,16 @@ as.data.frame.QuestionFormAnswers <- function(xml.parsed) {
                 out$SelectionIdentifier[z] <- multiple
                 out$Combined.Answers[z] <- multiple
                 rm(multiple)
-            } else if(length(xmlChildren(questions[[z]])$OtherSelectionField) == 1) {
+            } else if (length(xmlChildren(questions[[z]])$OtherSelectionField) == 1) {
                 out$OtherSelectionField[z] <- xmlValue(xmlChildren(questions[[z]])$OtherSelectionField)
                 out$Combined.Answers[z] <- xmlValue(xmlChildren(questions[[z]])$OtherSelectionField)
             }
         }
         return(out)
     }
-    values <- do.call(rbind,lapply(answers,FUN=convertxml))
-    return(values)
+    out <- do.call(rbind,lapply(answers,FUN=convertxml))
+    out[] <- lapply(out, function(x) if (is.character(x)) type.convert(x, as.is = TRUE) else x)
+    return(setRownames(out))
 }
 
 
@@ -451,9 +429,9 @@ as.data.frame.ReviewResults <- function(xml.parsed) {
                 AssignmentReviewAction = NULL, 
                 HITReviewResult = NULL, 
                 HITReviewAction = NULL)
-    if(!is.null(hit.xml) && length(hit.xml) >= 1) {
+    if (!is.null(hit.xml) && length(hit.xml) >= 1) {
         hit <- xmlValue(xpathApply(xml.parsed, "//HITId")[[1]])
-        if(length(xpathApply(xml.parsed, "//AssignmentReviewPolicy")) > 0)  {
+        if (length(xpathApply(xml.parsed, "//AssignmentReviewPolicy")) > 0)  {
             assignment.policy <- 
               xmlValue(xpathApply(xml.parsed, "//AssignmentReviewPolicy")[[1]])
             out$AssignmentResults <- as.numeric(xmlValue(xpathApply(xml.parsed, "//AssignmentReviewReport/NumResults")[[1]]))
@@ -463,27 +441,25 @@ as.data.frame.ReviewResults <- function(xml.parsed) {
             out$AssignmentResults <- 0
             out$AssignmentTotalResults <- 0
         }
-        if(length(xpathApply(xml.parsed, "//HITReviewPolicy")) > 0) {
+        if (length(xpathApply(xml.parsed, "//HITReviewPolicy")) > 0) {
             hit.policy <- xmlValue(xpathApply(xml.parsed, "//HITReviewPolicy")[[1]])
         } else {
             hit.policy <- NA
         }
-        if(!is.na(assignment.policy)) {
+        if (!is.na(assignment.policy)) {
             assignment.report <- 
               xmlChildren(xpathApply(xml.parsed, "//AssignmentReviewReport")[[1]])
-            if(!is.null(assignment.report) && length(assignment.report) >= 1) {
-                AssignmentReviewResult <- setNames(data.frame(matrix(
-                    nrow = sum(names(assignment.report) == "ReviewResult"), ncol=7)),
-                    c("AssignmentReviewPolicy", "ActionId", "SubjectId",
-                    "ObjectType", "QuestionId", "Key", "Value"))
-                AssignmentReviewAction <- setNames(data.frame(matrix(
-                    nrow = sum(names(assignment.report) == "ReviewAction"), ncol = 9)),
-                    c("AssignmentReviewPolicy", "ActionId", "ActionName", "ObjectId",
-                    "ObjectType", "Status", "CompleteTime", "Result", "ErrorCode"))
+            if (!is.null(assignment.report) && length(assignment.report) >= 1) {
+                AssignmentReviewResult <- emptydf(nrow = sum(names(assignment.report) == "ReviewResult"), ncol=7,
+                                                  c("AssignmentReviewPolicy", "ActionId", "SubjectId",
+                                                    "ObjectType", "QuestionId", "Key", "Value"))
+                AssignmentReviewAction <- emptydf(nrow = sum(names(assignment.report) == "ReviewAction"), ncol = 9,
+                                                  c("AssignmentReviewPolicy", "ActionId", "ActionName", "ObjectId",
+                                                    "ObjectType", "Status", "CompleteTime", "Result", "ErrorCode"))
                 r <- 1
                 a <- 1
-                for(i in 1:length(assignment.report)) {
-                    if(xmlName(assignment.report[[i]]) == "ReviewResult") {
+                for (i in 1:length(assignment.report)) {
+                    if (xmlName(assignment.report[[i]]) == "ReviewResult") {
                         AssignmentReviewResult$AssignmentReviewPolicy[r] <- assignment.policy
                         AssignmentReviewResult$ActionId[r] <- xmlValue(xmlChildren(assignment.report[[i]])$ActionId)
                         AssignmentReviewResult$SubjectId[r] <- xmlValue(xmlChildren(assignment.report[[i]])$SubjectId)
@@ -492,7 +468,7 @@ as.data.frame.ReviewResults <- function(xml.parsed) {
                         AssignmentReviewResult$Key[r] <- xmlValue(xmlChildren(assignment.report[[i]])$Key)
                         AssignmentReviewResult$Value[r] <- xmlValue(xmlChildren(assignment.report[[i]])$Value)
                         r <- r + 1
-                    } else if(xmlName(assignment.report[[i]]) == "ReviewAction") {
+                    } else if (xmlName(assignment.report[[i]]) == "ReviewAction") {
                         AssignmentReviewAction$AssignmentReviewPolicy[a] <- assignment.policy
                         AssignmentReviewAction$ActionId[a] <- xmlValue(xmlChildren(assignment.report[[i]])$ActionId)
                         AssignmentReviewAction$ActionName[a] <- xmlValue(xmlChildren(assignment.report[[i]])$ActionName)
@@ -508,30 +484,26 @@ as.data.frame.ReviewResults <- function(xml.parsed) {
                 out$AssignmentReviewResult <- AssignmentReviewResult
                 out$AssignmentReviewAction <- AssignmentReviewResult
             } else {
-                out$AssignmentReviewResult <- setNames(data.frame(matrix(nrow = 0, ncol=7)),
-                    c("AssignmentReviewPolicy", "ActionId", "SubjectId",
-                    "ObjectType", "QuestionId", "Key", "Value"))
-                out$AssignmentReviewAction <- setNames(data.frame(matrix(nrow = 0, ncol = 9)),
-                    c("AssignmentReviewPolicy", "ActionId", "ActionName", "ObjectId",
-                    "ObjectType", "Status", "CompleteTime", "Result", "ErrorCode"))
+                out$AssignmentReviewResult <- emptydf(0, 7, c("AssignmentReviewPolicy", "ActionId", "SubjectId",
+                                                              "ObjectType", "QuestionId", "Key", "Value"))
+                out$AssignmentReviewAction <- emptydf(0, 9, c("AssignmentReviewPolicy", "ActionId", "ActionName", "ObjectId",
+                                                              "ObjectType", "Status", "CompleteTime", "Result", "ErrorCode"))
             }
         }
-        if(!is.na(hit.policy)) {
+        if (!is.na(hit.policy)) {
             hit.report <- 
               xmlChildren(xpathApply(xml.parsed, "//HITReviewReport")[[1]])
-            if(!is.null(hit.report) && length(hit.report) >= 1) {
-                HITReviewResult <- setNames(data.frame(matrix(
-                    nrow = sum(names(hit.report) == "ReviewResult"), ncol = 7)),
-                    c("HITReviewPolicy", "ActionId", "SubjectId", "ObjectType",
-                    "QuestionId", "Key", "Value"))
-                HITReviewAction <- setNames(data.frame(matrix(
-                    nrow = sum(names(hit.report) == "ReviewAction"), ncol = 9)),
-                    c("HITReviewPolicy", "ActionId", "ActionName", "ObjectId",
-                    "ObjectType", "Status", "CompleteTime", "Result", "ErrorCode"))
+            if (!is.null(hit.report) && length(hit.report) >= 1) {
+                HITReviewResult <- emptydf(nrow = sum(names(hit.report) == "ReviewResult"), ncol = 7,  
+                                           c("HITReviewPolicy", "ActionId", "SubjectId", "ObjectType",
+                                             "QuestionId", "Key", "Value"))
+                HITReviewAction <- emptydf(nrow = sum(names(hit.report) == "ReviewAction"), ncol = 9,
+                                           c("HITReviewPolicy", "ActionId", "ActionName", "ObjectId",
+                                             "ObjectType", "Status", "CompleteTime", "Result", "ErrorCode"))
                 r <- 1
                 a <- 1
-                for(i in 1:length(hit.report)) {
-                    if(xmlName(hit.report[[i]]) == "ReviewResult") {
+                for (i in 1:length(hit.report)) {
+                    if (xmlName(hit.report[[i]]) == "ReviewResult") {
                         HITReviewResult$HITReviewPolicy[r] <- hit.policy
                         HITReviewResult$ActionId[r] <- xmlValue(xmlChildren(hit.report[[i]])$ActionId)
                         HITReviewResult$SubjectId[r] <- xmlValue(xmlChildren(hit.report[[i]])$SubjectId)
@@ -540,7 +512,7 @@ as.data.frame.ReviewResults <- function(xml.parsed) {
                         HITReviewResult$Key[r] <- xmlValue(xmlChildren(hit.report[[i]])$Key)
                         HITReviewResult$Value[r] <- xmlValue(xmlChildren(hit.report[[i]])$Value)
                         r <- r + 1
-                    } else if(xmlName(hit.report[[i]]) == "ReviewAction") {
+                    } else if (xmlName(hit.report[[i]]) == "ReviewAction") {
                         HITReviewAction$HITReviewPolicy[a] <- hit.policy
                         HITReviewAction$ActionId[a] <- xmlValue(xmlChildren(hit.report[[i]])$ActionId)
                         HITReviewAction$ActionName[a] <- xmlValue(xmlChildren(hit.report[[i]])$ActionName)
@@ -556,12 +528,9 @@ as.data.frame.ReviewResults <- function(xml.parsed) {
                 out$HITReviewResult <- HITReviewResult
                 out$HITReviewAction <- HITReviewAction
             } else {
-                out$HITReviewResult <- setNames(data.frame(matrix(nrow = 0, ncol = 7)),
-                    c("HITReviewPolicy", "ActionId", "SubjectId", "ObjectType",
-                    "QuestionId", "Key", "Value"))
-                out$HITReviewAction <- setNames(data.frame(matrix(nrow = 0, ncol = 9)),
-                    c("HITReviewPolicy", "ActionId", "ActionName", "ObjectId",
-                    "ObjectType", "Status", "CompleteTime", "Result", "ErrorCode"))
+                out$HITReviewResult <- emptydf(0, 7, c("HITReviewPolicy", "ActionId", "SubjectId", "ObjectType","QuestionId", "Key", "Value"))
+                out$HITReviewAction <- emptydf(0, 9, c("HITReviewPolicy", "ActionId", "ActionName", "ObjectId",
+                                                       "ObjectType", "Status", "CompleteTime", "Result", "ErrorCode"))
             }
         }
     }
@@ -585,17 +554,11 @@ as.data.frame.BonusPayments <- function(xml.parsed){
             GrantTime = xmlValue(children$GrantTime)
         ))
     })
-    if(!length(out)){
-        return(setNames(data.frame(matrix(nrow=0, ncol=7)),
-            c("AssignmentId",
-              "WorkerId",
-              "Amount",
-              "CurrencyCode",
-              "FormattedPrice",
-              "Reason",
-              "GrantTime")))
-    } else
-        return(do.call(rbind.data.frame,out))
+    if (!length(out)) {
+        return(emptydf(0, 7, c("AssignmentId","WorkerId","Amount","CurrencyCode","FormattedPrice","Reason","GrantTime")))
+    } else {
+        return(setRownames(do.call(rbind.data.frame,out)))
+    }
 }
 
 as.data.frame.WorkerBlock <- function(xml.parsed) {
@@ -606,11 +569,10 @@ as.data.frame.WorkerBlock <- function(xml.parsed) {
             Reason = xmlValue(children$Reason)
         ))
     })
-    if(!length(out)){
-        return(setNames(data.frame(matrix(nrow=0, ncol=2)),
-            c("WorkerId",
-              "Reason")))
-    } else
-        return(do.call(rbind.data.frame,out))
+    if (!length(out)) {
+        return(emptydf(0, 2, c("WorkerId", "Reason")))
+    } else {
+        return(setRownames(do.call(rbind.data.frame,out)))
+    }
 }
 
