@@ -1,16 +1,22 @@
 .onLoad <- function(libname, pkgname){
-    if(is.null(getOption("MTurkR.logdir")))
+    if (is.null(getOption("MTurkR.logdir"))) {
         options(MTurkR.logdir = getwd())    # MTurkRlog.tsv directory
-    if(is.null(getOption("MTurkR.sandbox")))
+    }
+    if (is.null(getOption("MTurkR.sandbox"))) {
         options(MTurkR.sandbox = FALSE)     # sandbox logical
-    if(is.null(getOption("MTurkR.verbose")))
+    }
+    if (is.null(getOption("MTurkR.verbose"))) {
         options(MTurkR.verbose = TRUE)      # print logical
-    if(is.null(getOption("MTurkR.browser")))
+    }
+    if (is.null(getOption("MTurkR.browser"))) {
         options(MTurkR.browser = FALSE)     # browser logical
-    if(is.null(getOption("MTurkR.log")))
+    }
+    if (is.null(getOption("MTurkR.log"))) {
         options(MTurkR.log = TRUE)          # log logical
-    if(is.null(getOption("MTurkR.test")))
+    }
+    if (is.null(getOption("MTurkR.test"))) {
         options(MTurkR.test = FALSE)        # validation.test logical
+    }
 }
 
 .onAttach <- function(libname, pkgname) {
